@@ -4,7 +4,7 @@
 
 """
 
-__version__ = "1.0.23"
+__version__ = "1.0.24"
 
 from binance.async_client import AsyncClient  # noqa
 from binance.client import Client  # noqa
@@ -18,4 +18,13 @@ from binance.ws.streams import (
     ThreadedWebsocketManager,  # noqa
     BinanceSocketType,  # noqa
 )
+
+from binance.ws.keepalive_websocket import KeepAliveWebsocket  # noqa
+
+from binance.ws.reconnecting_websocket import ReconnectingWebsocket  # noqa
+
+from binance.ws.constants import * # noqa
+
+from binance.exceptions import *  # noqa
+
 from binance.enums import *  # noqa
